#ifndef NT2_INCLUDE_CONSTANTS_CGOLD_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_CGOLD_HPP_INCLUDED

#include <nt2/constant/include/constants/cgold.hpp>

#endif
